validate_event_store_replay_source

Function validate_event_store_replay_source 

pub fn validate_event_store_replay_source(
    base_dir: impl Into<PathBuf>,
    instance_id: &str,
    run_id: &str,
) -> Result<RunManifest, CacheReplayError>
Validates that a configured replay source exists, is sealed, and is not quarantined.

Errors

Returns CacheReplayError::EventStore when the run is missing, not sealed, quarantined, or unreadable.