pub struct CatalogSlicePlan {
pub query: CatalogSliceQuery,
pub coverage: CatalogSliceCoverage,
}Expand description
Planned catalog slice joined to a replay input scan.
Fields
query: CatalogSliceQueryResolved catalog query.
coverage: CatalogSliceCoverageCatalog coverage reported during planning.
Implementations
Sourceimpl CatalogSlicePlan
impl CatalogSlicePlan
Sourcepub fn is_missing(&self) -> bool
pub fn is_missing(&self) -> bool
Returns whether the catalog reported no files for this slice.