pub fn replay_cache_snapshot_tail<B>(
cache: &mut Cache,
reader: &EventStoreReader<B>,
) -> Result<CacheReplayReport, CacheReplayError>where
B: EventStore,Expand description
Replays the cache snapshot tail when the cache snapshot has already been restored.
This is a convenience wrapper for callers that load the cache-owned snapshot blob before entering the event-store replay path.