pub fn restore_cache_snapshot_blob(
cache: &mut Cache,
anchor: Option<&SnapshotAnchor>,
) -> Result<(), CacheReplayError>Expand description
Restores the cache-owned snapshot blob identified by anchor.
Errors
Returns CacheReplayError::SnapshotRestore when the blob is missing, fails to load, fails its
content hash check, or fails to restore into the cache.